pub struct WsStream { /* private fields */ }Expand description
A Stream wrapper for WebSocket messages.
This struct wraps an mpsc::UnboundedReceiver<WsMessage> and implements
the Stream trait, enabling use of stream combinators.
Implementations
Sourceimpl WsStream
impl WsStream
Sourcepub fn new(receiver: UnboundedReceiver<WsMessage>) -> Self
pub fn new(receiver: UnboundedReceiver<WsMessage>) -> Self
Create a new WsStream from an unbounded receiver.
Sourcepub fn orderbooks(
self,
) -> impl Stream<Item = Box<WsStreamMessage<OrderbookData>>>
pub fn orderbooks( self, ) -> impl Stream<Item = Box<WsStreamMessage<OrderbookData>>>
Create a filtered stream that only yields orderbook messages.
Sourcepub fn trades(self) -> impl Stream<Item = Box<WsStreamMessage<Vec<TradeData>>>>
pub fn trades(self) -> impl Stream<Item = Box<WsStreamMessage<Vec<TradeData>>>>
Create a filtered stream that only yields trade messages.
Sourcepub fn tickers(self) -> impl Stream<Item = Box<WsStreamMessage<TickerData>>>
pub fn tickers(self) -> impl Stream<Item = Box<WsStreamMessage<TickerData>>>
Create a filtered stream that only yields ticker messages.
Sourcepub fn klines(self) -> impl Stream<Item = Box<WsStreamMessage<Vec<KlineData>>>>
pub fn klines(self) -> impl Stream<Item = Box<WsStreamMessage<Vec<KlineData>>>>
Create a filtered stream that only yields kline messages.
Sourcepub fn liquidations(
self,
) -> impl Stream<Item = Box<WsStreamMessage<LiquidationData>>>
pub fn liquidations( self, ) -> impl Stream<Item = Box<WsStreamMessage<LiquidationData>>>
Create a filtered stream that only yields liquidation messages.
Sourcepub fn operation_responses(self) -> impl Stream<Item = WsOperationResponse>
pub fn operation_responses(self) -> impl Stream<Item = WsOperationResponse>
Create a filtered stream that only yields operation responses.
Sourcepub fn positions(
self,
) -> impl Stream<Item = Box<WsPrivateMessage<Vec<PositionData>>>>
pub fn positions( self, ) -> impl Stream<Item = Box<WsPrivateMessage<Vec<PositionData>>>>
Create a filtered stream that only yields position updates (private stream).
Sourcepub fn orders(self) -> impl Stream<Item = Box<WsPrivateMessage<Vec<OrderData>>>>
pub fn orders(self) -> impl Stream<Item = Box<WsPrivateMessage<Vec<OrderData>>>>
Create a filtered stream that only yields order updates (private stream).
Sourcepub fn executions(
self,
) -> impl Stream<Item = Box<WsPrivateMessage<Vec<ExecutionData>>>>
pub fn executions( self, ) -> impl Stream<Item = Box<WsPrivateMessage<Vec<ExecutionData>>>>
Create a filtered stream that only yields execution updates (private stream).
Sourcepub fn executions_fast(
self,
) -> impl Stream<Item = Box<WsPrivateMessage<Vec<ExecutionFastData>>>>
pub fn executions_fast( self, ) -> impl Stream<Item = Box<WsPrivateMessage<Vec<ExecutionFastData>>>>
Create a filtered stream that only yields fast execution updates (private stream).
Sourcepub fn wallets(
self,
) -> impl Stream<Item = Box<WsPrivateMessage<Vec<WalletData>>>>
pub fn wallets( self, ) -> impl Stream<Item = Box<WsPrivateMessage<Vec<WalletData>>>>
Create a filtered stream that only yields wallet updates (private stream).
Sourcepub fn greeks(
self,
) -> impl Stream<Item = Box<WsPrivateMessage<Vec<GreeksData>>>>
pub fn greeks( self, ) -> impl Stream<Item = Box<WsPrivateMessage<Vec<GreeksData>>>>
Create a filtered stream that only yields greeks updates (private stream, options).